# Syengo Hello World Package

## Description

This is a simple python package conatining a hello_world function to test skills in python package publishing.

### Instructions

1.

```cmd
pip install syengohelloworldpackage
```

2. Import hello_world from Package
3. run func by providing an optional name= parameter

### License

MIT
